==> pmml-model-gwt-1.1.12-sources.jar: org/dmg/pmml/TextIndexNormalization.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.adapters.IntegerAdapter;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;choice minOccurs="0">
 *           &lt;element ref="{http://www.dmg.org/PMML-4_2}TableLocator"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_2}InlineTable"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="inField" type="{http://www.w3.org/2001/XMLSchema}string" default="string" />
 *       &lt;attribute name="outField" type="{http://www.w3.org/2001/XMLSchema}string" default="stem" />
 *       &lt;attribute name="regexField" type="{http://www.w3.org/2001/XMLSchema}string" default="regex" />
 *       &lt;attribute name="recursive" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="isCaseSensitive" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       &lt;attribute name="maxLevenshteinDistance" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="wordSeparatorCharacterRE" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="tokenize" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "tableLocator",
    "inlineTable"
})
@XmlRootElement(name = "TextIndexNormalization", namespace = "http://www.dmg.org/PMML-4_2")
@Added(Version.PMML_4_2)
public class TextIndexNormalization
    extends PMMLObject
    implements HasExtensions
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_2")
    protected List<Extension> extensions;
    @XmlElement(name = "TableLocator", namespace = "http://www.dmg.org/PMML-4_2")
    protected TableLocator tableLocator;
    @XmlElement(name = "InlineTable", namespace = "http://www.dmg.org/PMML-4_2")
    protected InlineTable inlineTable;
    @XmlAttribute(name = "inField")
    protected String inField;
    @XmlAttribute(name = "outField")
    protected String outField;
    @XmlAttribute(name = "regexField")
    protected String regexField;
    @XmlAttribute(name = "recursive")
    protected Boolean recursive;
    @XmlAttribute(name = "isCaseSensitive")
    protected Boolean isCaseSensitive;
    @XmlAttribute(name = "maxLevenshteinDistance")
    @XmlJavaTypeAdapter(IntegerAdapter.class)
    @XmlSchemaType(name = "integer")
    protected Integer maxLevenshteinDistance;
    @XmlAttribute(name = "wordSeparatorCharacterRE")
    protected String wordSeparatorCharacterRE;
    @XmlAttribute(name = "tokenize")
    protected Boolean tokenize;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the tableLocator property.
     * 
     * @return
     *     possible object is
     *     {@link TableLocator }
     *     
     */
    public TableLocator getTableLocator() {
        return tableLocator;
    }

    /**
     * Sets the value of the tableLocator property.
     * 
     * @param value
     *     allowed object is
     *     {@link TableLocator }
     *     
     */
    public void setTableLocator(TableLocator value) {
        this.tableLocator = value;
    }

    /**
     * Gets the value of the inlineTable property.
     * 
     * @return
     *     possible object is
     *     {@link InlineTable }
     *     
     */
    public InlineTable getInlineTable() {
        return inlineTable;
    }

    /**
     * Sets the value of the inlineTable property.
     * 
     * @param value
     *     allowed object is
     *     {@link InlineTable }
     *     
     */
    public void setInlineTable(InlineTable value) {
        this.inlineTable = value;
    }

    /**
     * Gets the value of the inField property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInField() {
        if (inField == null) {
            return "string";
        } else {
            return inField;
        }
    }

    /**
     * Sets the value of the inField property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInField(String value) {
        this.inField = value;
    }

    /**
     * Gets the value of the outField property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOutField() {
        if (outField == null) {
            return "stem";
        } else {
            return outField;
        }
    }

    /**
     * Sets the value of the outField property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOutField(String value) {
        this.outField = value;
    }

    /**
     * Gets the value of the regexField property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRegexField() {
        if (regexField == null) {
            return "regex";
        } else {
            return regexField;
        }
    }

    /**
     * Sets the value of the regexField property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRegexField(String value) {
        this.regexField = value;
    }

    /**
     * Gets the value of the recursive property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isRecursive() {
        if (recursive == null) {
            return false;
        } else {
            return recursive;
        }
    }

    /**
     * Sets the value of the recursive property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setRecursive(Boolean value) {
        this.recursive = value;
    }

    /**
     * Gets the value of the isCaseSensitive property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIsCaseSensitive() {
        return isCaseSensitive;
    }

    /**
     * Sets the value of the isCaseSensitive property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIsCaseSensitive(Boolean value) {
        this.isCaseSensitive = value;
    }

    /**
     * Gets the value of the maxLevenshteinDistance property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getMaxLevenshteinDistance() {
        return maxLevenshteinDistance;
    }

    /**
     * Sets the value of the maxLevenshteinDistance property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMaxLevenshteinDistance(Integer value) {
        this.maxLevenshteinDistance = value;
    }

    /**
     * Gets the value of the wordSeparatorCharacterRE property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWordSeparatorCharacterRE() {
        return wordSeparatorCharacterRE;
    }

    /**
     * Sets the value of the wordSeparatorCharacterRE property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWordSeparatorCharacterRE(String value) {
        this.wordSeparatorCharacterRE = value;
    }

    /**
     * Gets the value of the tokenize property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isTokenize() {
        return tokenize;
    }

    /**
     * Sets the value of the tokenize property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setTokenize(Boolean value) {
        this.tokenize = value;
    }

    public TextIndexNormalization withExtensions(Extension... values) {
        if (values!= null) {
            for (Extension value: values) {
                getExtensions().add(value);
            }
        }
        return this;
    }

    public TextIndexNormalization withExtensions(Collection<Extension> values) {
        if (values!= null) {
            getExtensions().addAll(values);
        }
        return this;
    }

    public TextIndexNormalization withTableLocator(TableLocator value) {
        setTableLocator(value);
        return this;
    }

    public TextIndexNormalization withInlineTable(InlineTable value) {
        setInlineTable(value);
        return this;
    }

    public TextIndexNormalization withInField(String value) {
        setInField(value);
        return this;
    }

    public TextIndexNormalization withOutField(String value) {
        setOutField(value);
        return this;
    }

    public TextIndexNormalization withRegexField(String value) {
        setRegexField(value);
        return this;
    }

    public TextIndexNormalization withRecursive(Boolean value) {
        setRecursive(value);
        return this;
    }

    public TextIndexNormalization withIsCaseSensitive(Boolean value) {
        setIsCaseSensitive(value);
        return this;
    }

    public TextIndexNormalization withMaxLevenshteinDistance(Integer value) {
        setMaxLevenshteinDistance(value);
        return this;
    }

    public TextIndexNormalization withWordSeparatorCharacterRE(String value) {
        setWordSeparatorCharacterRE(value);
        return this;
    }

    public TextIndexNormalization withTokenize(Boolean value) {
        setTokenize(value);
        return this;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.extensions!= null))&&(i<this.extensions.size())); i ++) {
            status = this.extensions.get(i).accept(visitor);
        }
        if ((status == VisitorAction.CONTINUE)&&(this.tableLocator!= null)) {
            status = this.tableLocator.accept(visitor);
        }
        if ((status == VisitorAction.CONTINUE)&&(this.inlineTable!= null)) {
            status = this.inlineTable.accept(visitor);
        }
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.3.5-sources.jar: org/dmg/pmml/TextIndexNormalization.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;choice minOccurs="0">
 *           &lt;element ref="{http://www.dmg.org/PMML-4_3}TableLocator"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_3}InlineTable"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *       &lt;attribute name="inField" type="{http://www.w3.org/2001/XMLSchema}string" default="string" />
 *       &lt;attribute name="outField" type="{http://www.w3.org/2001/XMLSchema}string" default="stem" />
 *       &lt;attribute name="regexField" type="{http://www.w3.org/2001/XMLSchema}string" default="regex" />
 *       &lt;attribute name="recursive" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="isCaseSensitive" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       &lt;attribute name="maxLevenshteinDistance" type="{http://www.dmg.org/PMML-4_3}INT-NUMBER" />
 *       &lt;attribute name="wordSeparatorCharacterRE" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="tokenize" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "tableLocator",
    "inlineTable"
})
@XmlRootElement(name = "TextIndexNormalization", namespace = "http://www.dmg.org/PMML-4_3")
@Added(Version.PMML_4_2)
public class TextIndexNormalization
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<TextIndexNormalization> , HasTable<TextIndexNormalization>
{

    @XmlAttribute(name = "inField")
    private String inField;
    @XmlAttribute(name = "outField")
    private String outField;
    @XmlAttribute(name = "regexField")
    private String regexField;
    @XmlAttribute(name = "recursive")
    private Boolean recursive;
    @XmlAttribute(name = "isCaseSensitive")
    private Boolean caseSensitive;
    @XmlAttribute(name = "maxLevenshteinDistance")
    private Integer maxLevenshteinDistance;
    @XmlAttribute(name = "wordSeparatorCharacterRE")
    private String wordSeparatorCharacterRE;
    @XmlAttribute(name = "tokenize")
    private Boolean tokenize;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    private List<Extension> extensions;
    @XmlElement(name = "TableLocator", namespace = "http://www.dmg.org/PMML-4_3")
    private TableLocator tableLocator;
    @XmlElement(name = "InlineTable", namespace = "http://www.dmg.org/PMML-4_3")
    private InlineTable inlineTable;
    private final static Boolean DEFAULT_RECURSIVE = false;

    /**
     * Gets the value of the inField property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInField() {
        if (inField == null) {
            return "string";
        } else {
            return inField;
        }
    }

    /**
     * Sets the value of the inField property.
     * 
     * @param inField
     *     allowed object is
     *     {@link String }
     *     
     */
    public TextIndexNormalization setInField(String inField) {
        this.inField = inField;
        return this;
    }

    /**
     * Gets the value of the outField property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOutField() {
        if (outField == null) {
            return "stem";
        } else {
            return outField;
        }
    }

    /**
     * Sets the value of the outField property.
     * 
     * @param outField
     *     allowed object is
     *     {@link String }
     *     
     */
    public TextIndexNormalization setOutField(String outField) {
        this.outField = outField;
        return this;
    }

    /**
     * Gets the value of the regexField property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRegexField() {
        if (regexField == null) {
            return "regex";
        } else {
            return regexField;
        }
    }

    /**
     * Sets the value of the regexField property.
     * 
     * @param regexField
     *     allowed object is
     *     {@link String }
     *     
     */
    public TextIndexNormalization setRegexField(String regexField) {
        this.regexField = regexField;
        return this;
    }

    /**
     * Gets the value of the recursive property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isRecursive() {
        if (recursive == null) {
            return DEFAULT_RECURSIVE;
        } else {
            return recursive;
        }
    }

    /**
     * Sets the value of the recursive property.
     * 
     * @param recursive
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public TextIndexNormalization setRecursive(Boolean recursive) {
        this.recursive = recursive;
        return this;
    }

    /**
     * Gets the value of the caseSensitive property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isCaseSensitive() {
        return caseSensitive;
    }

    /**
     * Sets the value of the caseSensitive property.
     * 
     * @param caseSensitive
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public TextIndexNormalization setCaseSensitive(Boolean caseSensitive) {
        this.caseSensitive = caseSensitive;
        return this;
    }

    /**
     * Gets the value of the maxLevenshteinDistance property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getMaxLevenshteinDistance() {
        return maxLevenshteinDistance;
    }

    /**
     * Sets the value of the maxLevenshteinDistance property.
     * 
     * @param maxLevenshteinDistance
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public TextIndexNormalization setMaxLevenshteinDistance(Integer maxLevenshteinDistance) {
        this.maxLevenshteinDistance = maxLevenshteinDistance;
        return this;
    }

    /**
     * Gets the value of the wordSeparatorCharacterRE property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWordSeparatorCharacterRE() {
        return wordSeparatorCharacterRE;
    }

    /**
     * Sets the value of the wordSeparatorCharacterRE property.
     * 
     * @param wordSeparatorCharacterRE
     *     allowed object is
     *     {@link String }
     *     
     */
    public TextIndexNormalization setWordSeparatorCharacterRE(String wordSeparatorCharacterRE) {
        this.wordSeparatorCharacterRE = wordSeparatorCharacterRE;
        return this;
    }

    /**
     * Gets the value of the tokenize property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isTokenize() {
        return tokenize;
    }

    /**
     * Sets the value of the tokenize property.
     * 
     * @param tokenize
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public TextIndexNormalization setTokenize(Boolean tokenize) {
        this.tokenize = tokenize;
        return this;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the tableLocator property.
     * 
     * @return
     *     possible object is
     *     {@link TableLocator }
     *     
     */
    public TableLocator getTableLocator() {
        return tableLocator;
    }

    /**
     * Sets the value of the tableLocator property.
     * 
     * @param tableLocator
     *     allowed object is
     *     {@link TableLocator }
     *     
     */
    public TextIndexNormalization setTableLocator(TableLocator tableLocator) {
        this.tableLocator = tableLocator;
        return this;
    }

    /**
     * Gets the value of the inlineTable property.
     * 
     * @return
     *     possible object is
     *     {@link InlineTable }
     *     
     */
    public InlineTable getInlineTable() {
        return inlineTable;
    }

    /**
     * Sets the value of the inlineTable property.
     * 
     * @param inlineTable
     *     allowed object is
     *     {@link InlineTable }
     *     
     */
    public TextIndexNormalization setInlineTable(InlineTable inlineTable) {
        this.inlineTable = inlineTable;
        return this;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public TextIndexNormalization addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getTableLocator(), getInlineTable());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
